@@ -4,7 +4,7 @@ import doctest
 import glob
 
 def load_tests(loader, tests, ignore):
-    fl=glob.glob("dtwr/*.py")
+    fl=glob.glob("dtw/*.py")
     tests.addTests(doctest.DocFileSuite(*fl,module_relative=False))
     return tests
 
